import matematikk as mt

def enhet_og_pris_fra_inntekt_max(pris_uttrykk_hs = mt.Symbol("2*x + 1"),
                                  pris_desimal    = -1,
                                  enhet_vari      = mt.Symbol("x"),
                                  enhet_desimal   = None,
                                  enhet_debug     = - 1):

    # Variabler
    x = enhet_vari
    p = pris_uttrykk_hs

    # Definerer uttrykket for inntekts-funksjonen, I(x)
    I = x * p

    # Deriverer I mhp. x og får dI = 66.8 - 12.2*log(x)
    dI = mt.deriver(I, x) # I'(x)

    # Løser likningen dI = 0
    x_inntekt_max = mt.superløs(variabel = x,
                                vs       = dI,
                                hs       = 0,
                                rund     = enhet_desimal,
                                debug    = enhet_debug)

    # Setter x_inntekt_max = 239 inn i p og definerer det nye uttrykket som p_inntekt_max
    p_inntekt_max = p.subs(x, x_inntekt_max)

    # Henter verdien til p_inntekt_max
    p_inntekt_max_val = p_inntekt_max.evalf()

    # Runder av 12.1871446664356 -> 12.20
    p_inntekt_max_val = round(p_inntekt_max_val, pris_desimal)

    return [x_inntekt_max, p_inntekt_max_val]

# Alias > 1 ...

# Alias > 2 > ...
enhet_og_pris_fra_inntekt_max = enhet_og_pris_fra_inntekt_max




# 🚀 programmering.no | 🤓 matematikk.as
# S2 - Eksamen - 2023 Høst (Udir)
# Oppgave 4) Areal med bestemt integral - Bestemt integral og areal 

N = 1000
start = -2
slutt = 2
dx = (slutt - start)/N

def f(x):
	return x**2-1

S = 0
for i in range(N):
	xi = start + i*dx
	S = S + abs(f(xi))*dx # abs(f(x)) gir absoluttverdien til f(x)

print(S)



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av to tall

# Input
a = input("Tall 1: ")
b = input("Tall 2: ")

# Sum-funksjon for to tall
def to_tall_sum(a, b):

    # Regn ut summen
    c = float(a) + float(b)

    return c

# Sum
c = to_tall_sum(a, b)

# Print
print(f"Summen er: {a} + {b} = {c}")



# 🚀 programmering.no | 🤓 matematikk.as
# S2 - Eksamen - 2023 Vår (Matematikk AS)
# Oppgave 4 b) Aritmetisk- og geometrisk rekke - Uker før tilbud 2 gir mer ukelønn enn tilbud 1 

lonn_0      = 100       # Ukelønn første uke
a_n         = lonn_0    # Tilbud 1: Ukelønn første uke
a_d         = 10        # Tilbud 1: Aritmetisk økning (differanse)
g_n         = lonn_0    # Tilbud 2: Ukelønn første uke
g_k         = 1.05      # Tilbud 2: Geometrisk økning (kvotient)
uker        = 1         # Antall uker
desimal     = 2         # Antall desimaler i avrunding

# Print-funksjon
def printing_rader(i, tilbud, belop): print(f"Uke {i} | Tilbud {tilbud} | Beløp: {round(belop, desimal)}")

# Oppgave b)
print("Oppg b)")

# Kjøres så lenge geometrisk ukelønn er lavere enn aritmetisk
while g_n <= a_n:
    printing_rader(uker, "1 (A)", a_n); a_n += a_d  # Aritmetisk formel
    printing_rader(uker, "2 (G)", g_n); g_n *= g_k  # Geometrisk formel
    print("")                                       # Blank linje
    uker += 1                                       # Uker øker med 1

# Print svar
print(f"Etter {uker} uker er geometrisk ukelønn størst ({round(g_n, desimal)} > {a_n})")



# 🚀 programmering.no | 🤓 matematikk.as
# S2 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 1 c) Etterspørsel - Størst inntekt 
# - Løser oppgaven med CAS i Python
# - Kopier denne kommandoen i terminalen for å importere matematikk: 
#   $ pip install matematikk

import matematikk as mt
    
# Variabler
x                   = mt.Symbol("x")        # Etterspørsel (antall produserte enheter)
x_desimal           = None                  # Avrunding (heltall)
p                   = mt.Symbol("p")        # Pris per enhet
p_desimal           = 1                     # Avrunding
I                   = mt.Symbol("I")        # Inntekt
svar_c_ls           = list()                # Svar-setninger

# Definerer uttrykket for pris-funksjonen, p(x)
p = 79 - 12.2 * mt.ln(x)

# Definerer uttrykket for inntekts-funksjonen, I(x)
I = x * p

# Deriverer I mhp. x og får dI = 66.8 - 12.2*log(x)
dI = mt.deriver(I, x) # I'(x)

# Løser likningen dI = 0
x_inntekt_max = mt.superløs(variabel = x,
                            vs       = dI,
                            hs       = 0,
                            rund     = x_desimal,
                            debug    = -1)

# Setter x_inntekt_max = 239 inn i p og definerer det nye uttrykket som p_inntekt_max
p_inntekt_max = p.subs(x, x_inntekt_max)

# Henter verdien til p_inntekt_max
p_inntekt_max_val = p_inntekt_max.evalf()

# Runder av 12.1871446664356 -> 12.20
p_inntekt_max_val = round(p_inntekt_max_val, p_desimal)

# Svar-setninger
svar_c_ls.append(f"")
svar_c_ls.append(f"Oppg c)")
svar_c_ls.append(f"")
svar_c_ls.append(f"- Inntekten er størst når etterspørselen er ca. {x_inntekt_max} enheter")
svar_c_ls.append(f"- Dette gir en pris på ca. {p_inntekt_max_val} kr")

# Print svar-setninger
for svar in svar_c_ls: print(svar)



# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på range (intervall) med steg

# Variabler
intervall = range(4, 20, 2) # Husk 20 + 1 hvis øvre grense skal inkluderes

# For-løkken hopper 2 steg for hver iterasjon
for tall in intervall:
    print(tall)



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut arealet av en sirkel med enhet

# Verdier
pi = 3.14

# Input
enhet = input("Velg enhet: ")
r = input("Sirkelens radius er: ")

# Areal-funksjon for sirkel
def sirkel_areal(r):

    # Formel for arealet av sirkel
    areal = pi * float(r)**2

    return areal

# Areal
areal = sirkel_areal(r)

# Print
print(f"Arealet er:: {areal} {enhet}^2")



# 🚀 programmering.no | 🤓 matematikk.as
# - Kopier liste med copy()

# Verdier
liste = ["A", "B", "C"]

# Kopier liste
liste_copy = liste.copy()

# Print
print(f"Original liste : {liste}")
print(f"Kopiert liste  : {liste_copy}")



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av to matriser med numpy

import numpy as np

# Verdier
matrise_A = np.array([[1, 2], [3, 4]])
matrise_B = np.array([[4, 5], [6, 7]])

# Print
print("")
print("Matrise A:")
print(matrise_A)
print("")
print("Matrise B:")
print(matrise_B)

# Summer matrise A og B
matrise_sum = np.add(matrise_A, matrise_B)

# Print
print("")
print("Matrise A + B:")
print(matrise_sum)



# 🚀 programmering.no | 🤓 matematikk.as
# 1T - Eksamen - 2022 Vår (Udir)
# Oppgave 4 a) Kvadrattallene fra 1 til 160 000 - Forklar koden 

def f(x):
	return x ** 2   # Definerer funksjonen f gitt ved f(x) = x ^ 2

x = 1

while x <= 400:
    print(f(x))
    x = x + 1



# 🚀 programmering.no | 🤓 matematikk.as
# - Hvordan bruke indeks for å få tak i en bokstav (char) med for-løkke

# Variabler
pyt = "Python 🐍"

# For hver iterasjon printes neste bokstav (char)
for i in range(len(pyt)):
    print(pyt[i])



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 5 b) Volum av prisme - Maksimalt volum av kassen 

from sympy import Symbol, diff, solve, solveset, Eq, Reals

# definerer symboler
s = Symbol("s")
h = Symbol("h")

# Set opp likningane
A = s**2 + 4*s*h
V = s**2 * h

# Finn uttrykk for h når A=120 og s=5
A_2 = A.subs(s, 5)
likning = Eq(A_2, 120)
løysing = solveset(likning, h, domain=Reals)
print(løysing)



# 🚀 programmering.no | 🤓 matematikk.as
# - Sletter alle elementene i en liste

# Verdier
liste = ["Juni", "Juli", "August"]

# Print
print(f"Liste: {liste}")

# Slett alle el i listen
liste = []

# Print
print(f"Liste: {liste}")



# 🚀 programmering.no | 🤓 matematikk.as
# S2 - Eksamen - 2023 Vår (Matematikk AS)
# Oppgave 4 a), b) og c) Aritmetisk- og geometrisk rekke 

_blokk = 1
if _blokk == 1:
    lonn_0      = 100       # Ukelønn første uke
    a_n         = float()   # Tilbud 1: Ukelønn første uke
    a_d         = 10        # Tilbud 1: Aritmetisk økning (differanse)
    a_s         = 0         # Tilbud 1: Aritmetisk sum
    g_n         = float()   # Tilbud 2: Ukelønn første uke
    g_k         = 1.05      # Tilbud 2: Geometrisk økning (kvotient)
    g_s         = 0         # Tilbud 2: Geometrisk sum
    uker        = int()     # Antall uker
    desimal     = 2         # Antall desimaler i avrund

# Print-funksjon
def printing_rader(uker, tilbud, belop): print(f"Uke {uker} | Tilbud {tilbud} | Beløp: {round(belop, desimal)}")

# Oppgave a)
if _blokk == 1:

    # Print
    print("")
    print("Oppg a)")

    # Variabler
    a_n     = lonn_0
    g_n     = lonn_0
    uker    = 4

    # Aritmetisk rekke
    print("")
    for i in range(uker + 1): printing_rader(uker, "1 (A)", a_n); a_n += a_d;

    # Geometrisk rekke
    print("")
    for i in range(uker + 1): printing_rader(uker, "1 (G)", g_n); g_n *= g_k;

# Oppgave b)
if _blokk == 1:

    # Print
    print("")
    print("Oppg b)")

    # Variabler
    a_n     = lonn_0
    g_n     = lonn_0
    uker    = 1

    # Kjøres så lenge geometrisk ukelønn er lavere enn aritmetisk
    while g_n <= a_n:
        printing_rader(uker, "1 (A)", a_n); a_n += a_d  # Aritmetisk formel
        printing_rader(uker, "2 (G)", g_n); g_n *= g_k  # Geometrisk formel
        print("")
        uker += 1    # Uker øker med 1

    # Print svar
    print(f"Etter {uker} uker er geometrisk ukelønn størst ({round(g_n, desimal)} > {a_n})")

# Oppgave c)
if _blokk == 1:

    # Print
    print("")
    print("Oppg c)")

    # Variabler
    a_n     = lonn_0
    g_n     = lonn_0
    uker    = 1

    # Kjøres så lenge geometrisk ukelønn er lavere enn aritmetisk
    while g_s <= a_s:
        a_s  += a_n  # Aritmetisk sum
        a_n  += a_d  # Aritmetisk formel
        g_s  += g_n  # Geometrisk sum
        g_n  *= g_k  # Geometrisk formel
        printing_rader(uker, "1 (A)", a_s);
        printing_rader(uker, "2 (G)", g_s);
        print("")
        uker += 1    # Uker øker med 1

    # Trekker fra 1 uke
    uker -= 1

    # Print svar
    print(f"Etter {uker} uker er den geometrisk summen størst ({round(g_s, desimal)} > {a_s})")



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Matematikk AS)
# Oppgave 2 b) Venstrehendte - P("Minst 3 venstrehendte gutter") > 0.2 
# - Oppgave-teksten har antageligvis en feil (som dette programmet fikser)
# - Feilen er at ordet "MINST" ikke er tatt med
#   - "Hvor mange gutter må det (MINST) være i en klasse dersom
#      sannsynligheten for at minst tre av guttene er
#      venstrehendte, skal være større enn 20 prosent?"
# - Grunnen til at dette blir feil, er at man uten ordet "MINST" bare kunne sagt
#   et veldig stort antall gutter (f.eks. 1000 eller "uendelig")
# - Fordi hvis man kun spør om "hvor mange gutter det må være for at
#   denne sannsynligheten skal være større enn 20 %", så vil jo denne
#   sannsynligheten selvfølgelig raskt bli mye større enn 20 % når det er veldig
#   mange gutter i klassen, og det kun er snakk om 3 venstrehendte der
# - Derfor er det fornuftig å heller finne det minste antallet gutter i klassen
#   (grensetilfelle), som gjør at denne sannsynligheten akkurat blir større enn 20 %

import numpy as np # lala

# Konstanter
_blokk             = 1         # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker
p_vh               = 0.1       # Sannsynligheten for at gutt er venstrehendt (vh)
k_vh               = 3         # Utvalget k med vh i klassen er 3 eller større
n_klasse           = 1         # Gutter i klassen (starter på 1 eller k_vh)
m_klasse           = 1000      # Mulige utfall (alle klasse-simuleringene)
m_klasse_liste     = list()    # Liste med mulige utfall (fra simuleringene)
g_klasse           = int()     # Gunstige utfall (fra simuleringene)
sannsyn_gitt       = 0.2       # Sannsynligheten for at k gutter i klassen er vh (gitt i oppg)
sannsyn_sim        = float()   # Sannsynligheten for at k gutter i klassen er vh (simulert)

# Definer tilfeldighets-generatoren (random number generator)
rng = np.random.default_rng()

# Definerer funksjoner
def sannsynlighet_for_minst_3_vh(n_klasse):

    # Regner ut sannsynligheten for k antall vh i en klasse med n_klasse gutter (se while-løkke)

    # Simulering steg-for-steg
    if _blokk == -1:
        # 1. En endring fra oppg a) er at antall gutter starter på 1 og kan øke
        # 2. Etter første simulering sammenlignes sannsynligheten med 20 %
        # 3. Hvis den er mindre enn 20 % øker klassen med 1 gutt
        # 4. Da gjøres simuleringen om igjen med den nye verdien for n_klasse
        # 5. Denne gutten blir så enten vh eller ikke, 1 eller 0
        # 6. Gjør dette n_klasse ganger og får f.eks. 0, 0, 1, 0 og 1 (hvis n_klasse er 5)
        # 7. Teller hvor mange av de n_klasse som ble vh, f.eks. 2
        # 8. Legger 2 i listen, [2]
        # 9. Gjør dette med 1000 klasser, [2, 0, 0, ..., 1]
        # 10. m_skole_liste får dermed alle utfallene (fra simuleringen)
        pass
    m_klasse_liste = rng.binomial(n = n_klasse, p = p_vh, size = m_klasse)

    # Tell gunstige utfall (alle klasser med 3 eller flere vh)
    g_klasse = sum(m_klasse_liste >= k_vh)

    # Definisjonen av sannsynlighet gir P(VH) = g / m, der hendelsen VH: "Gutt på skolen er vh"
    sannsyn_sim = g_klasse / m_klasse

    # Returnerer sannsynligheten tilbake til while-løkken
    return sannsyn_sim

# While-løkke steg-for-steg
if _blokk == -1:
    # 1. Løkken kaller først sannsynlighet_for_minst_3_vh() med
    #    argumentet n_klasse (nåværende gutter i klassen)
    # 2. sannsynlighet_for_minst_3_vh() returnerer sannsyn_sim (sannsynligheten
    #    for vh i en klasse med n_klasse gutter, se simulerings-steg)
    # 3. Hvis sannsyn_sim < 20 % (betingelsen), så øker n_klasse med 1
    # 4. Isåfall kaller løkken sannsynlighet_for_minst_3_vh() om igjen
    # 5. Løkken vil da repeterer dette til sannsyn_sim >= 20 % (betingelsen brytes)
    pass

# Regner ut sannsynligheten for k antall vh i en klasse med n_klasse gutter (se while-løkke)
while sannsynlighet_for_minst_3_vh(n_klasse) < sannsyn_gitt:

    # n_klasse øker med 1 hver gang løkken (og simuleringen) kjøres
    n_klasse += 1

# Lag svar-setninger
svar_1 = f"Når det skal være større enn 20 % sannsynlighet for at"
svar_2 = f"minst {k_vh} gutter i klassen er venstrehendte,"
svar_3 = f"så må det være minst {n_klasse} gutter i klassen"

# Print svar-setninger
print("")
print(svar_1)
print(svar_2)
print(svar_3)



# 🚀 programmering.no | 🤓 matematikk.as
# S1 - Eksamen - 2023 Høst (Torodd)
# Oppgave 6 a) Tredjegradsfunksjon - Påstand 1: Grafen f har minst ett ekstremalpunkt 

from sympy import symbols, diff, solve, solveset, Eq, Reals

# Grafen til f har minst ett ekstremalpunkt
# Hvis f skal ha minst ett ekstremalpunkt må f`ha minst ett nullpunkt

# definerer symboler
x, a, b, c, d = symbols("x a b c d")

# definerer f
f = a*x**3 + b*x**2 + c*x + d

# deriverer f
df = diff(f, x)

# finn nullpunkta til f'(x)
løysingar = solveset(Eq(df, 0), x, domain=Reals)
print(løysingar)



# 🚀 programmering.no | 🤓 matematikk.as
# S2 - Eksamen - 2023 Vår (NDLA)
# Oppgave 4 b) Aritmetisk- og geometrisk rekke - Uker før tilbud 2 gir mer ukelønn enn tilbud 1 

an = 100            # setter startverdi
bn = 100            # setter startverdi
n = 1               # setter startverdi
while bn <= an:
    n = n + 1       # oppdaterer verdien til n
    an = an + 10    # oppdaterer verdien til an
    bn = bn*1.05    # oppdaterer verdien til bn

print(f"I den {n} uka får hun for første gang mer med tilbud 2.")



# 🚀 programmering.no | 🤓 matematikk.as
# - Del en liste opp i mindre lister med n elementer i hver liste

# Verdier
liste   = [
                    "a", "b", "c", "d", "e", "f", "g", "h", "i", "j",
                    "k", "l", "m", "n", "o", "p", "q", "r", "s", "s",
                    "u", "v", "w", "x", "y", "z"
                ]
n_deler = 3

# Del opp listen i del-lister med n elementer i hver del-liste
def oppdeling_lister(liste, n):

	# Itererer gjennom listen
	for i in range(0, len(liste), n):

		# Yield returner del-lister uten å bryte ut av loopen
		yield liste[i : i + n]

# Del-lister
del_lister = list(oppdeling_lister(liste, int(n_deler)))

# Print
print(f"Del-lister (hele): {del_lister}")
print("Del-lister (en og en):")
for del_liste in del_lister:
	print(f"{del_liste}")



# 🚀 programmering.no | 🤓 matematikk.as
# - En pyramiden bygges av kvadratiske lag
# - Det er 10 000 klosser tilgjengelig
# - 1) Finn antall klosser i fig. nr n
# - 2) Finn totalt antall klosser til og med fig nr n
# - 3) Finn ut hvor mange pyramider som kan lages

# Verdier
ant_max      = 10000    # Antall klosser tilgjengelig
ant_fig      = 0        # Antall klosser i nåværende figur nr. n
ant_totalt   = 0        # Antall klosser totalt til og med figur nr. n
n            = 1        # Figur nr.

# Iterer så lenge totalt antall klosser er mindre eller lik 10000
while ant_totalt <= ant_max:

    # Oppdater antall klosser i nåværende figur nr. og total bruk
    ant_fig      += n**2
    ant_totalt   += ant_fig

    # Print nåværende resultater (før n inkrementeres)
    print("")
    print(f"Fig nr : {n}")
    print(f"I fig  : {ant_fig}")
    print(f"Totalt : {ant_totalt}")

    # Inkrementer n (etter print)
    n += 1



# 🚀 programmering.no | 🤓 matematikk.as
# Sinus 1T (2020) - BrettBoka - 1.5 Formler (s. 55) 
# Oppgave 9 Tittel (Matematikk AS)

from math import sqrt

# Blokk med definisjoner
_blokk             = 1 # 0: Av, 1: På, Skjul/debug deler av koden med if-blokker
if _blokk == 1:

    # Konstanter
    katet_1_a          = 3             # Trekant A: Lengden til katet 1, f.eks. [m]
    katet_2_a          = 4             # Trekant A: Lengden til katet 2, [m]
    hypotenus_a        = 5             # Trekant A: Lengden til hypotenus, [m]
    katet_1_b          = 105           # Trekant B: Lengden til katet 1, [m]
    katet_2_b          = 208           # Trekant B: Lengden til katet 2, [m]
    hypotenus_b        = 233           # Trekant B: Lengden til hypotenus, [m]

    # Enheter
    enhet_m            = "m"           # Meter

    # Tekst
    txt_oppg           = "Oppg 9 - Kapitteltest 1"
    txt_strek          = "-----------------------"
    txt_a_1            = "a) Trekant A: Lengden til katet 1   :"
    txt_a_2            = "   Trekant A: Lengden til katet 2   :"
    txt_a_3            = "   Trekant A: Lengden til hypotenus :"
    txt_b_1            = "b) Trekant B: Lengden til katet 1   :"
    txt_b_2            = "   Trekant B: Lengden til katet 2   :"
    txt_b_3            = "   Trekant B: Lengden til hypotenus :"
    txt_info_1         = "   h^2 = k_1^2 + k_2^2, Pythagoras teorem"
    txt_info_2         = "a) h = √(k_1^2 + k_2^2)"
    txt_info_3         = "b) k_1^2 + k_2^2 = h^2"
    txt_info_4         = "   k_2^2 = h^2 - k_1^2"
    txt_info_5         = "   k_2 = √(h^2 - k_1^2)"
    txt_error          = "Kateter kan ikke være lengre enn hypotenus"
    txt_ikke_def       = "Ikke definert"

    # Innstillinger
    inp                = 1             # # 0: Boken, 1: Bruker
    avrund_valg        = 1             # # 0: Ikke avrunding, 1: Avrunding
    avrund_ant         = None          # # None: 12.78 -> 13, 0: 12.78 -> 13.0, 1: 12.78 -> 12.8, 2: 12.78 -> 12.78

# Input
print("")
print(txt_strek)
print(txt_oppg)
print(txt_strek)
if inp == 1:
    print("")
    katet_1_a = input("a) Trekant A: Hva er lengden til katet 1 [m]? ")
    katet_2_a = input("a) Trekant A: Hva er lengden til katet 2 [m]? ")
    katet_1_b = input("b) Trekant B: Hva er lengden til katet 1 [m]? ")
    hypotenus_b = input("b) Trekant B: Hva er lengden til hypotenus [m]? ")

# Type casting: str -> float
katet_1_a          = float(katet_1_a)
katet_2_a          = float(katet_2_a)
katet_1_b          = float(katet_1_b)
hypotenus_b        = float(hypotenus_b)

# a) Trekant A: Lengden til hypotenus
hypotenus_a        = sqrt(katet_1_a**2 + katet_2_a**2)

# b) Trekant B: Lengden til katet 2
try:
    # Prøv om lengdene er ok
    katet_2_b      = sqrt(hypotenus_b**2 - katet_1_b**2)

    # Avrunding
    if avrund_valg == 1:
        katet_1_a       = round(katet_1_a, avrund_ant)
        katet_2_a       = round(katet_2_a, avrund_ant)
        hypotenus_a     = round(hypotenus_a, avrund_ant)
        katet_1_b       = round(katet_1_b, avrund_ant)
        katet_2_b       = round(katet_2_b, avrund_ant)
        hypotenus_b     = round(hypotenus_b, avrund_ant)
except:
    # Lengdene er ikke definert
    print("")
    print(txt_error)
    hypotenus_b    = txt_ikke_def
    katet_2_b      = txt_ikke_def

# Print
print("")
print(txt_info_1)
print(txt_info_2)
print(txt_info_3)
print(txt_info_4)
print(txt_info_5)
print("")
print(txt_a_1, katet_1_a, enhet_m)
print(txt_a_2, katet_2_a, enhet_m)
print(txt_a_3, hypotenus_a, enhet_m)
print(txt_b_1, katet_1_b, enhet_m)
print(txt_b_2, katet_2_b, enhet_m)
print(txt_b_3, hypotenus_b, enhet_m)
print("")



# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av de n første kvadratene i rekken

# Input
n = input("Antall kvadrater (n): ")

# Sum-funksjon for n kvadrater
def rekke_n_kvadrater_sum(n):

    # Nullstill
    sum = 0

    # For-løkken oppdaterer sum for hver iterasjon
    for i in range(int(n) + 1):
        sum = sum + pow(i, 2)

    return sum

# Summer n kvadrater
sum = rekke_n_kvadrater_sum(n)

# Print
print(f"Summen av de {n} første kvadratene er: {sum}")
